from setuptools import setup

setup(name='jcao',
      version='0.1',
      description='This is test only',
      url='/home/jcao/repos/personal/study/pkg',
      author='jcao',
      author_email='zongbo_cao@163.com',
      license='MIT',
      packages=['pkg'],
      zip_safe=False)